@@ -19,36 +19,21 @@
 #ifndef _PSENSOR_COLOR_H_
 #define _PSENSOR_COLOR_H_
 
-/*
- * Represents a RGB color.
- *
- * Contains integer and floating RGB representation to avoid useless
- * conversion.
- *
- * Uses color_set to maintain the coherence of the both
- * representation.
- */
+/* Represents a RGB color. */
 struct color {
-	/* rgb 0..65535 */
-	unsigned int red;
-	unsigned int green;
-	unsigned int blue;
-
 	/* rgb floating 0..1 */
-	double f_red;
-	double f_green;
-	double f_blue;
+	double red;
+	double green;
+	double blue;
 };
 
-struct color *
-color_new(unsigned int red, unsigned int green, unsigned int blue);
+/** rgb 0..1 */
+struct color *color_new(double r, double g, double b);
 
 struct color *color_dup(struct color *);
 
-void color_set(struct color *,
-	       unsigned int red,
-	       unsigned int green,
-	       unsigned int blue);
+/** rgb 0..1 */
+void color_set(struct color *, double r, double g, double b);
 
 int is_color(const char *str);
 
