@@ -23,15 +23,11 @@
 #include "psensor.h"
 
 #ifdef HAVE_ATASMART
-struct psensor **hdd_psensor_list_add(struct psensor **sensors,
-				      int values_max_length);
-
-void hdd_psensor_list_update(struct psensor **sensors);
+void atasmart_psensor_list_append(struct psensor ***sensors, int values_length);
+void atasmart_psensor_list_update(struct psensor **sensors);
 #endif
 
-struct psensor **hddtemp_psensor_list_add(struct psensor **sensors,
-				      int values_max_length);
-
+void hddtemp_psensor_list_append(struct psensor ***sensors, int values_length);
 void hddtemp_psensor_list_update(struct psensor **sensors);
 
 #endif
