@@ -27,10 +27,12 @@
 #include <sensors/sensors.h>
 #include <sensors/error.h>
 
-#include "psensor.h"
+#include <psensor.h>
 
 static int init_done;
 
+static const char *PROVIDER_NAME = "lmsensor";
+
 static double get_value(const sensors_chip_name *name,
 			const sensors_subfeature *sub)
 {
@@ -39,8 +41,10 @@ static double get_value(const sensors_chip_name *name,
 
 	err = sensors_get_value(name, sub->number, &val);
 	if (err) {
-		log_err(_("lmsensor: cannot get value of subfeature %s: %s."),
-			sub->name, sensors_strerror(err));
+		log_err(_("%s: Cannot get value of subfeature %s: %s."),
+			PROVIDER_NAME,
+			sub->name,
+			sensors_strerror(err));
 		val = UNKNOWN_DBL_VALUE;
 	}
 	return val;
@@ -48,17 +52,22 @@ static double get_value(const sensors_chip_name *name,
 
 static double get_temp_input(struct psensor *sensor)
 {
-	const sensors_chip_name *chip = sensor->iname;
-	const sensors_feature *feature = sensor->feature;
-
 	const sensors_subfeature *sf;
 
-	sf = sensors_get_subfeature(chip,
-				    feature, SENSORS_SUBFEATURE_TEMP_INPUT);
+	const sensors_chip_name *chip;
+
+	const sensors_feature *feature;
+
+	chip = sensor->iname;
+	feature = sensor->feature;
+
+	sf = sensors_get_subfeature(sensor->iname,
+				    feature,
+				    SENSORS_SUBFEATURE_TEMP_INPUT);
 	if (sf)
 		return get_value(chip, sf);
-	else
-		return UNKNOWN_DBL_VALUE;
+
+	return UNKNOWN_DBL_VALUE;
 }
 
 static double get_fan_input(struct psensor *sensor)
@@ -69,33 +78,39 @@ static double get_fan_input(struct psensor *sensor)
 	const sensors_subfeature *sf;
 
 	sf = sensors_get_subfeature(chip,
-				    feature, SENSORS_SUBFEATURE_FAN_INPUT);
+				    feature,
+				    SENSORS_SUBFEATURE_FAN_INPUT);
+
 	if (sf)
 		return get_value(chip, sf);
-	else
-		return UNKNOWN_DBL_VALUE;
+
+	return UNKNOWN_DBL_VALUE;
 }
 
 void lmsensor_psensor_list_update(struct psensor **sensors)
 {
-	struct psensor **s_ptr = sensors;
+	struct psensor *s;
+	double v;
 
 	if (!init_done)
-		return ;
+		return;
 
-	while (*s_ptr) {
-		struct psensor *s = *s_ptr;
+	while (*sensors) {
+		s = *sensors;
 
 		if (!(s->type & SENSOR_TYPE_REMOTE)
 		    && s->type & SENSOR_TYPE_LMSENSOR) {
+
 			if (s->type & SENSOR_TYPE_TEMP)
-				psensor_set_current_value(s,
-							  get_temp_input(s));
-			else if (s->type & SENSOR_TYPE_RPM)
-				psensor_set_current_value(s, get_fan_input(s));
+				v = get_temp_input(s);
+			else /* s->type & SENSOR_TYPE_RPM */
+				v = get_fan_input(s);
+
+			if (v != UNKNOWN_DBL_VALUE)
+				psensor_set_current_value(s, v);
 		}
 
-		s_ptr++;
+		sensors++;
 	}
 }
 
@@ -119,8 +134,7 @@ lmsensor_psensor_create(const sensors_chip_name *chip,
 	} else if (feature->type == SENSORS_FEATURE_FAN) {
 		fault_subfeature = SENSORS_SUBFEATURE_FAN_FAULT;
 	} else {
-		log_err(_(
-"lmsensor: lmsensor_psensor_create failure: wrong feature type."));
+		log_err(_("%s: Wrong feature type."), PROVIDER_NAME);
 		return NULL;
 	}
 
@@ -140,9 +154,13 @@ lmsensor_psensor_create(const sensors_chip_name *chip,
 	else
 		return NULL;
 
-	id = malloc(strlen("lmsensor ") + 1 + strlen(name) + 1 + strlen(label) +
-		    1);
-	sprintf(id, "lmsensor %s %s", name, label);
+	id = malloc(strlen(PROVIDER_NAME)
+		    + 1
+		    + strlen(name)
+		    + 1
+		    + strlen(label)
+		    + 1);
+	sprintf(id, "%s %s %s", PROVIDER_NAME, name, label);
 
 	if (!strcmp(chip->prefix, "coretemp"))
 		cname = strdup(_("Intel CPU"));
@@ -154,6 +172,8 @@ lmsensor_psensor_create(const sensors_chip_name *chip,
 		cname = strdup(_("NVIDIA GPU"));
 	else if (!strcmp(chip->prefix, "via-cputemp"))
 		cname = strdup(_("VIA CPU"));
+	else if (!strcmp(chip->prefix, "acpitz"))
+		cname = strdup(_("ACPI"));
 	else
 		cname = strdup(chip->prefix);
 
@@ -171,56 +191,50 @@ lmsensor_psensor_create(const sensors_chip_name *chip,
 	return psensor;
 }
 
-struct psensor **lmsensor_psensor_list_add(struct psensor **sensors,
-					   int vn)
+void lmsensor_init()
+{
+	int err;
+
+	err = sensors_init(NULL);
+
+	if (err) {
+		log_err(_("%s: initialization failure: %s."),
+			PROVIDER_NAME,
+			sensors_strerror(err));
+		init_done = 0;
+	} else {
+		init_done = 1;
+	}
+}
+
+void lmsensor_psensor_list_append(struct psensor ***sensors, int vn)
 {
 	const sensors_chip_name *chip;
-	int chip_nr = 0;
-	struct psensor **tmp, **result;
+	int chip_nr, i;
 	const sensors_feature *feature;
 	struct psensor *s;
-	int i;
 
 	if (!init_done)
-		return NULL;
+		lmsensor_init();
 
-	result = sensors;
+	if (!init_done)
+		return;
+
+	chip_nr = 0;
 	while ((chip = sensors_get_detected_chips(NULL, &chip_nr))) {
 
 		i = 0;
 		while ((feature = sensors_get_features(chip, &i))) {
-
 			if (feature->type == SENSORS_FEATURE_TEMP
 			    || feature->type == SENSORS_FEATURE_FAN) {
 
 				s = lmsensor_psensor_create(chip, feature, vn);
 
-				if (s) {
-					tmp = psensor_list_add(result, s);
-
-					if (tmp != sensors)
-						free(result);
-
-					result = tmp;
-				}
+				if (s)
+					psensor_list_append(sensors, s);
 			}
 		}
 	}
-
-	return result;
-}
-
-void lmsensor_init()
-{
-	int err = sensors_init(NULL);
-
-	if (err) {
-		log_err(_("lmsensor: initialization failure: %s."),
-			sensors_strerror(err));
-		init_done = 0;
-	} else {
-		init_done = 1;
-	}
 }
 
 void lmsensor_cleanup()
