@@ -35,7 +35,7 @@ enum psensor_type {
 	/* type of sensor values */
 	SENSOR_TYPE_TEMP = 0x00001,
 	SENSOR_TYPE_RPM = 0x00002,
-	SENSOR_TYPE_USAGE = 0x00004,
+	SENSOR_TYPE_PERCENT = 0x00004,
 
 	/* Whether the sensor is remote */
 	SENSOR_TYPE_REMOTE = 0x00008,
@@ -47,6 +47,7 @@ enum psensor_type {
 	SENSOR_TYPE_ATIADL = 0x00800,
 	SENSOR_TYPE_ATASMART = 0x01000,
 	SENSOR_TYPE_HDDTEMP = 0x02000,
+	SENSOR_TYPE_UDISKS2 = 0x800000,
 
 	/* Type of HW component */
 	SENSOR_TYPE_HDD = 0x04000,
@@ -54,9 +55,15 @@ enum psensor_type {
 	SENSOR_TYPE_GPU = 0x10000,
 	SENSOR_TYPE_FAN = 0x20000,
 
+	SENSOR_TYPE_GRAPHICS = 0x40000,
+	SENSOR_TYPE_VIDEO = 0x80000,
+	SENSOR_TYPE_PCIE = 0x100000,
+	SENSOR_TYPE_MEMORY = 0x200000,
+	SENSOR_TYPE_AMBIENT = 0x400000,
+
 	/* Combinations */
 	SENSOR_TYPE_HDD_TEMP = (SENSOR_TYPE_HDD | SENSOR_TYPE_TEMP),
-	SENSOR_TYPE_CPU_USAGE = (SENSOR_TYPE_CPU | SENSOR_TYPE_USAGE)
+	SENSOR_TYPE_CPU_USAGE = (SENSOR_TYPE_CPU | SENSOR_TYPE_PERCENT)
 };
 
 struct psensor {
@@ -71,13 +78,14 @@ struct psensor {
 
 	/* lm-sensor */
 	const sensors_chip_name *iname;
+
 	const sensors_feature *feature;
 
 	/* Maximum length of 'values' */
 	int values_max_length;
 
 	/* Last registered measures of the sensor.  Index 0 for the
-	   oldest measure.  */
+	 * oldest measure.  */
 	struct measure *measures;
 
 	/* Color of the sensor used for the graph */
@@ -104,7 +112,7 @@ struct psensor {
 	/* Whether an alarm is raised for this sensor */
 	unsigned int alarm_raised;
 
-	void (*cb_alarm_raised) (struct psensor *, void *);
+	void (*cb_alarm_raised)(struct psensor *, void *);
 	void *cb_alarm_raised_data;
 
 #ifdef HAVE_NVIDIA
@@ -118,6 +126,10 @@ struct psensor {
 #ifdef HAVE_ATASMART
 	SkDisk *disk;
 #endif
+
+	void *provider_data;
+	void (*provider_data_free_fct)(void *);
+
 	char *url;
 
 	bool appindicator_enabled;
@@ -141,13 +153,7 @@ struct psensor **psensor_list_filter_graph_enabled(struct psensor **);
 struct psensor *psensor_list_get_by_id(struct psensor **sensors,
 				       const char *id);
 
-/*
-  Return 1 if there is at least one sensor of a given type, else
-  returns 0 */
-int psensor_list_contains_type(struct psensor **sensors, unsigned int type);
-
 int is_temp_type(unsigned int type);
-int is_fan_type(unsigned int type);
 
 double get_min_temp(struct psensor **sensors);
 double get_max_temp(struct psensor **sensors);
@@ -155,18 +161,16 @@ double get_max_temp(struct psensor **sensors);
 double get_min_rpm(struct psensor **sensors);
 double get_max_rpm(struct psensor **sensors);
 
-/*
-  Get the maximal current value of all sensors of a given type.
-*/
+/* Get the maximal current value of all sensors of a given type. */
 double
 psensor_get_max_current_value(struct psensor **sensors, unsigned int type);
 
 /*
-  Converts the value of a sensor to a string.
-
-  parameter 'type' is SENSOR_TYPE_LMSENSOR_TEMP, SENSOR_TYPE_NVIDIA,
-  or SENSOR_TYPE_LMSENSOR_FAN
-*/
+ * Converts the value of a sensor to a string.
+ *
+ * parameter 'type' is SENSOR_TYPE_LMSENSOR_TEMP, SENSOR_TYPE_NVIDIA,
+ * or SENSOR_TYPE_LMSENSOR_FAN
+ */
 char *psensor_value_to_str(unsigned int type,
 			   double value,
 			   int use_celsius);
@@ -180,6 +184,8 @@ struct psensor **get_all_sensors(int use_libatasmart, int values_max_length);
 struct psensor **psensor_list_add(struct psensor **sensors,
 				  struct psensor *sensor);
 
+void psensor_list_append(struct psensor ***sensors, struct psensor *sensor);
+
 struct psensor **psensor_list_copy(struct psensor **);
 
 void psensor_set_current_value(struct psensor *sensor, double value);
@@ -190,24 +196,13 @@ double psensor_get_current_value(const struct psensor *);
 
 struct measure *psensor_get_current_measure(struct psensor *sensor);
 
-/*
-  Returns a string representation of a psensor type.
-*/
+/* Returns a string representation of a psensor type. */
 const char *psensor_type_to_str(unsigned int type);
 
 const char *psensor_type_to_unit_str(unsigned int type, int use_celsius);
 
-void psensor_list_update_measures(struct psensor **sensors);
-
-void psensor_init();
-
-void psensor_cleanup();
-
 double get_max_value(struct psensor **sensors, int type);
 
-double celsius_to_fahrenheit(double c);
-double fahrenheit_to_celsius(double c);
-
 char *psensor_current_value_to_str(const struct psensor *, unsigned int);
 
 void psensor_log_measures(struct psensor **sensors);
