@@ -34,6 +34,7 @@
 #include "bool.h"
 #include "config.h"
 #include <plog.h>
+#include <pmutex.h>
 #include "ptime.h"
 #include "slog.h"
 
@@ -57,12 +58,11 @@ static char *time_to_str(time_t *t)
 
 	str = malloc(64);
 
-	if (strftime(str, 64, "%s", &lt)) {
+	if (strftime(str, 64, "%s", &lt))
 		return str;
-	} else {
-		free(str);
-		return NULL;
-	}
+
+	free(str);
+	return NULL;
 }
 
 static char *get_default_path()
@@ -82,10 +82,10 @@ static char *get_default_path()
 		free(dir);
 
 		return path;
-	} else {
-		log_warn(_("HOME variable not set."));
-		return strdup(DEFAULT_FILENAME);
 	}
+
+	log_warn(_("HOME variable not set."));
+	return strdup(DEFAULT_FILENAME);
 }
 
 static bool slog_open(const char *path, struct psensor **sensors)
@@ -133,8 +133,8 @@ static void slog_write_sensors(struct psensor **sensors)
 	bool first_call;
 
 	if (!file) {
-		log_err(_("Sensor log file not open."));
-		return ;
+		log_debug(_("Sensor log file not open."));
+		return;
 	}
 
 	gettimeofday(&tv, NULL);
@@ -169,9 +169,9 @@ static void *slog_routine(void *data)
 {
 	while (1) {
 		pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL);
-		pthread_mutex_lock(sensors_mutex);
+		pmutex_lock(sensors_mutex);
 		slog_write_sensors(sensors);
-		pthread_mutex_unlock(sensors_mutex);
+		pmutex_unlock(sensors_mutex);
 		pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL);
 		sleep(period);
 	}
