@@ -78,16 +78,23 @@ on_delete_event_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
 
 void ui_show_about_dialog()
 {
+	static const char *const authors[] = { "jeanfi@gmail.com", NULL };
+
 	gtk_show_about_dialog
 		(NULL,
+		 "authors", authors,
 		 "comments",
 		 _("Psensor is a GTK+ application for monitoring hardware "
 		   "sensors"),
 		 "copyright",
-		 _("Copyright(c) 2010-2014\njeanfi@gmail.com"),
+		 _("Copyright(c) 2010-2014 jeanfi@gmail.com"),
+#if GTK_CHECK_VERSION(3, 12, 0)
+		 "license-type", GTK_LICENSE_GPL_2_0,
+#endif
 		 "logo-icon-name", "psensor",
 		 "program-name", "Psensor",
 		 "title", _("About Psensor"),
+		 "translator-credits", _("translator-credits"),
 		 "version", VERSION,
 		 "website", PACKAGE_URL,
 		 "website-label", _("Psensor Homepage"),
@@ -152,8 +159,7 @@ void ui_enable_alpha_channel(struct ui_psensor *ui)
 	}
 }
 
-static void
-slog_enabled_cbk(GConfClient *client, guint id, GConfEntry *e, gpointer data)
+static void slog_enabled_cbk(void *data)
 {
 	struct ui_psensor *ui;
 	struct psensor **sensors;
@@ -192,7 +198,7 @@ void ui_window_create(struct ui_psensor *ui)
 	if (!ok) {
 		log_printf(LOG_ERR, error->message);
 		g_error_free(error);
-		return ;
+		return;
 	}
 
 	window = GTK_WIDGET(gtk_builder_get_object(builder, "window"));
@@ -203,7 +209,7 @@ void ui_window_create(struct ui_psensor *ui)
 				cfg->window_x,
 				cfg->window_y);
 
-	config_slog_enabled_notify_add(slog_enabled_cbk, ui);
+	config_set_slog_enabled_changed_cbk(slog_enabled_cbk, ui);
 
 	gtk_window_set_default_size(GTK_WINDOW(window),
 				    cfg->window_w,
