@@ -19,12 +19,12 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "ui.h"
-#include "ui_pref.h"
-#include "ui_sensorlist.h"
-#include "ui_sensorpref.h"
-#include "cfg.h"
-#include "ui_color.h"
+#include <cfg.h>
+#include <ui.h>
+#include <ui_color.h>
+#include <ui_pref.h>
+#include <ui_sensorlist.h>
+#include <ui_sensorpref.h>
 
 enum {
 	COL_NAME = 0,
@@ -33,9 +33,10 @@ enum {
 	COL_TEMP_MAX,
 	COL_COLOR,
 	COL_COLOR_STR,
-	COL_ENABLED,
+	COL_GRAPH_ENABLED,
 	COL_EMPTY,
 	COL_SENSOR,
+	COL_DISPLAY_ENABLED
 };
 
 struct cb_data {
@@ -46,7 +47,7 @@ struct cb_data {
 static int col_index_to_col(int idx)
 {
 	if (idx == 5)
-		return COL_ENABLED;
+		return COL_GRAPH_ENABLED;
 	else if (idx > 5)
 		return -1;
 
@@ -57,9 +58,10 @@ static void populate(struct ui_psensor *ui)
 {
 	GtkTreeIter iter;
 	GtkListStore *store;
-	GdkColor color;
+	GdkRGBA color;
 	char *scolor;
 	struct psensor **ordered_sensors, **s_cur, *s;
+	unsigned int enabled;
 
 	ordered_sensors = ui_get_sensors_ordered_by_position(ui);
 	store = ui->sensors_store;
@@ -74,14 +76,18 @@ static void populate(struct ui_psensor *ui)
 		color.red = s->color->red;
 		color.green = s->color->green;
 		color.blue = s->color->blue;
+		color.alpha = 1.0;
 
-		scolor = gdk_color_to_string(&color);
+		scolor = gdk_rgba_to_string(&color);
+
+		enabled = config_is_sensor_enabled(s->id);
 
 		gtk_list_store_set(store, &iter,
 				   COL_NAME, s->name,
 				   COL_COLOR_STR, scolor,
-				   COL_ENABLED, s->graph_enabled,
+				   COL_GRAPH_ENABLED, s->graph_enabled,
 				   COL_SENSOR, s,
+				   COL_DISPLAY_ENABLED, enabled,
 				   -1);
 		free(scolor);
 	}
@@ -102,6 +108,8 @@ void ui_sensorlist_update(struct ui_psensor *ui, bool complete)
 		populate(ui);
 
 	model = gtk_tree_view_get_model(ui->sensors_tree);
+	model = gtk_tree_model_filter_get_model(GTK_TREE_MODEL_FILTER(model));
+
 	store = ui->sensors_store;
 
 	use_celsius = ui->config->temperature_unit == CELSIUS;
@@ -176,8 +184,8 @@ static int get_col_index_at_pos(GtkTreeView *view, int x)
 		if (x >= colx
 		    && x < (colx + gtk_tree_view_column_get_width(checkcol)))
 			return coli;
-		else
-			colx += gtk_tree_view_column_get_width(checkcol);
+
+		colx += gtk_tree_view_column_get_width(checkcol);
 
 		coli++;
 	}
@@ -187,9 +195,46 @@ static int get_col_index_at_pos(GtkTreeView *view, int x)
 
 static void preferences_activated_cbk(GtkWidget *menu_item, gpointer data)
 {
-	struct cb_data *cb_data = data;
+	struct cb_data *cb_data;
 
+	cb_data = data;
 	ui_sensorpref_dialog_run(cb_data->sensor, cb_data->ui);
+	free(cb_data);
+}
+
+static void hide_activated_cbk(GtkWidget *menu_item, gpointer data)
+{
+	struct psensor *s, *s2;
+	GtkTreeModel *model, *fmodel;
+	GtkTreeIter iter;
+	struct cb_data *cb_data;
+	gboolean valid;
+
+	log_fct_enter();
+
+	cb_data = data;
+	s = cb_data->sensor;
+	config_set_sensor_enabled(s->id, false);
+	config_sync();
+
+	fmodel = gtk_tree_view_get_model(cb_data->ui->sensors_tree);
+	model = gtk_tree_model_filter_get_model(GTK_TREE_MODEL_FILTER(fmodel));
+	valid = gtk_tree_model_get_iter_first(model, &iter);
+	while (valid) {
+		gtk_tree_model_get(model, &iter, COL_SENSOR, &s2, -1);
+
+		if (s == s2)
+			gtk_list_store_set(cb_data->ui->sensors_store,
+					   &iter,
+					   COL_DISPLAY_ENABLED,
+					   false,
+					   -1);
+		valid = gtk_tree_model_iter_next(model, &iter);
+	}
+
+	free(cb_data);
+
+	log_fct_exit();
 }
 
 static GtkWidget *
@@ -206,13 +251,22 @@ create_sensor_popup(struct ui_psensor *ui, struct psensor *sensor)
 	separator = gtk_separator_menu_item_new();
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu), separator);
 
+	item = gtk_menu_item_new_with_label(_("Hide"));
+	gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
+
+	data = malloc(sizeof(struct cb_data));
+	data->ui = ui;
+	data->sensor = sensor;
+	g_signal_connect(item,
+			 "activate",
+			 G_CALLBACK(hide_activated_cbk), data);
+
 	item = gtk_menu_item_new_with_label(_("Preferences"));
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
 
 	data = malloc(sizeof(struct cb_data));
 	data->ui = ui;
 	data->sensor = sensor;
-
 	g_signal_connect(item,
 			 "activate",
 			 G_CALLBACK(preferences_activated_cbk), data);
@@ -230,9 +284,6 @@ static int clicked_cbk(GtkWidget *widget, GdkEventButton *event, gpointer data)
 	struct psensor *s;
 	int coli;
 
-	if (event->button != 3)
-		return FALSE;
-
 	ui = (struct ui_psensor *)data;
 	view = ui->sensors_tree;
 
@@ -242,108 +293,84 @@ static int clicked_cbk(GtkWidget *widget, GdkEventButton *event, gpointer data)
 		coli = col_index_to_col(get_col_index_at_pos(view, event->x));
 
 		if (coli == COL_COLOR) {
-			if (ui_change_color(_("Select foreground color"),
+			if (ui_change_color(_("Select sensor color"),
 					    s->color,
 					    GTK_WINDOW(ui->main_window))) {
 				ui_sensorlist_update(ui, 1);
 				config_set_sensor_color(s->id, s->color);
+				config_sync();
 			}
-		} else if (coli >= 0 && coli != COL_ENABLED) {
+			return TRUE;
+		} else if (coli >= 0 && coli != COL_GRAPH_ENABLED) {
 			menu = create_sensor_popup(ui, s);
 
 			gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL,
 				       event->button, event->time);
+			return TRUE;
 		}
 
 	}
-	return TRUE;
+	return FALSE;
 }
 
-static void
-toggled_cbk(GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
+void ui_sensorlist_cb_graph_toggled(GtkCellRendererToggle *cell,
+				    gchar *path_str,
+				    gpointer data)
 {
 	struct ui_psensor *ui;
-	GtkTreeModel *model;
+	GtkTreeModel *model, *fmodel;
 	GtkTreeIter iter;
 	GtkTreePath *path;
-	struct psensor *s;
+	struct psensor *s, *s2;
+	gboolean valid;
 
 	ui = (struct ui_psensor *)data;
-	model = gtk_tree_view_get_model(ui->sensors_tree);
+	fmodel = gtk_tree_view_get_model(ui->sensors_tree);
+
 	path = gtk_tree_path_new_from_string(path_str);
 
-	gtk_tree_model_get_iter(model, &iter, path);
+	gtk_tree_model_get_iter(fmodel, &iter, path);
 
-	gtk_tree_model_get(model, &iter, COL_SENSOR, &s, -1);
+	gtk_tree_model_get(fmodel, &iter, COL_SENSOR, &s, -1);
 
 	s->graph_enabled ^= 1;
-	config_set_sensor_enabled(s->id, s->graph_enabled);
-
-	gtk_list_store_set(GTK_LIST_STORE(model), &iter,
-			   COL_ENABLED, s->graph_enabled, -1);
+	config_set_sensor_graph_enabled(s->id, s->graph_enabled);
+	config_sync();
 
 	gtk_tree_path_free(path);
+
+	model = gtk_tree_model_filter_get_model(GTK_TREE_MODEL_FILTER(fmodel));
+	valid = gtk_tree_model_get_iter_first(model, &iter);
+	while (valid) {
+		gtk_tree_model_get(model, &iter, COL_SENSOR, &s2, -1);
+
+		if (s == s2)
+			gtk_list_store_set(ui->sensors_store,
+					   &iter,
+					   COL_GRAPH_ENABLED,
+					   s->graph_enabled,
+					   -1);
+		valid = gtk_tree_model_iter_next(model, &iter);
+	}
 }
 
 void ui_sensorlist_create(struct ui_psensor *ui)
 {
-	GtkCellRenderer *renderer;
+	GtkTreeModel *fmodel, *model;
 
-	log_debug("ui_sensorlist_create()");
+	log_fct_enter();
 
-	renderer = gtk_cell_renderer_text_new();
-	gtk_tree_view_insert_column_with_attributes(ui->sensors_tree,
-						    -1,
-						    _("Sensor"),
-						    renderer,
-						    "text", COL_NAME, NULL);
+	model = gtk_tree_view_get_model(ui->sensors_tree);
+	fmodel = gtk_tree_model_filter_new(model, NULL);
+	gtk_tree_model_filter_set_visible_column(GTK_TREE_MODEL_FILTER(fmodel),
+						 COL_DISPLAY_ENABLED);
 
-	gtk_tree_view_insert_column_with_attributes(ui->sensors_tree,
-						    -1,
-						    _("Value"),
-						    renderer,
-						    "text", COL_TEMP, NULL);
-
-	gtk_tree_view_insert_column_with_attributes(ui->sensors_tree,
-						    -1,
-						    _("Min"),
-						    renderer,
-						    "text", COL_TEMP_MIN, NULL);
-
-	gtk_tree_view_insert_column_with_attributes(ui->sensors_tree,
-						    -1,
-						    _("Max"),
-						    renderer,
-						    "text", COL_TEMP_MAX, NULL);
-
-	renderer = gtk_cell_renderer_text_new();
-	gtk_tree_view_insert_column_with_attributes(ui->sensors_tree,
-						    -1,
-						    _("Color"),
-						    renderer,
-						    "text", COL_COLOR,
-						    "background", COL_COLOR_STR,
-						    NULL);
+	gtk_tree_view_set_model(ui->sensors_tree, fmodel);
 
 	g_signal_connect(ui->sensors_tree,
 			 "button-press-event", (GCallback)clicked_cbk, ui);
 
-	renderer = gtk_cell_renderer_toggle_new();
-	gtk_tree_view_insert_column_with_attributes(ui->sensors_tree,
-						    -1,
-						    _("Graph"),
-						    renderer,
-						    "active", COL_ENABLED,
-						    NULL);
-	g_signal_connect(G_OBJECT(renderer),
-			 "toggled", (GCallback) toggled_cbk, ui);
-
-	renderer = gtk_cell_renderer_text_new();
-	gtk_tree_view_insert_column_with_attributes(ui->sensors_tree,
-						    -1,
-						    "",
-						    renderer,
-						    "text", COL_EMPTY, NULL);
-
 	ui_sensorlist_update(ui, 1);
+
+	log_fct_exit();
 }
